import { transformError as sdkTransformError } from '@wix/sdk-runtime/transform-error';
import { renameKeysFromSDKRequestToRESTRequest } from '@wix/sdk-runtime/rename-all-nested-keys';
import * as ambassadorWixMultilingualGenericconverterV1EntityMapper from './multilingual-genericconverter-v1-entity-mapper-entity-mapper.http.js';
export var FieldType;
(function (FieldType) {
    /** Undefined field type */
    FieldType["UNDEFINED_TYPE"] = "UNDEFINED_TYPE";
    /** Short text TEXT */
    FieldType["SHORT_TEXT"] = "SHORT_TEXT";
    /** Long Plain Text TEXT */
    FieldType["LONG_TEXT"] = "LONG_TEXT";
    /** Long text including styles, images, links and more... HTML */
    FieldType["RICH_TEXT"] = "RICH_TEXT";
    /** Wix Rich-Content-Editor format RICO */
    FieldType["RICH_CONTENT_EDITOR"] = "RICH_CONTENT_EDITOR";
    /** Choose one from many options CSV TEXT */
    FieldType["SELECTION"] = "SELECTION";
    /** Choose multi items from many options */
    FieldType["MULTI_SELECTION"] = "MULTI_SELECTION";
    /** Wix document media item */
    FieldType["DOCUMENT"] = "DOCUMENT";
    /** Wix Image media item */
    FieldType["IMAGE"] = "IMAGE";
    /** Wix Video media item */
    FieldType["VIDEO"] = "VIDEO";
    /** Image URL without metadata */
    FieldType["IMAGE_LINK"] = "IMAGE_LINK";
})(FieldType || (FieldType = {}));
export var SchemaScope;
(function (SchemaScope) {
    /** Global schema, relevant to all sites */
    SchemaScope["GLOBAL"] = "GLOBAL";
    /** Site schema, relevant to specific site only */
    SchemaScope["SITE"] = "SITE";
})(SchemaScope || (SchemaScope = {}));
export var WebhookIdentityType;
(function (WebhookIdentityType) {
    WebhookIdentityType["UNKNOWN"] = "UNKNOWN";
    WebhookIdentityType["ANONYMOUS_VISITOR"] = "ANONYMOUS_VISITOR";
    WebhookIdentityType["MEMBER"] = "MEMBER";
    WebhookIdentityType["WIX_USER"] = "WIX_USER";
    WebhookIdentityType["APP"] = "APP";
})(WebhookIdentityType || (WebhookIdentityType = {}));
/**
 * Update localization content with editor data
 * @public
 * @documentationMaturity preview
 * @permissionId WIX_MULTILINGUAL.TRANSLATE_APPS
 * @fqn wix.multilingual.editoradapter.v1.EditorAdapter.SyncEditorData
 */
export async function syncEditorData(options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        syncFilter: options?.syncFilter,
    });
    const reqOpts = ambassadorWixMultilingualGenericconverterV1EntityMapper.syncEditorData(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { syncFilter: '$[0].syncFilter' },
            singleArgumentUnchanged: false,
        }, ['options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
//# sourceMappingURL=multilingual-genericconverter-v1-entity-mapper-entity-mapper.universal.js.map